/*
 * Copyright (c) 1997-1999 by Sun Microsystems, Inc. All Rights Reserved.
 */


import javax.swing.plaf.*;
import javax.swing.plaf.basic.*;
import javax.swing.plaf.metal.*;
import javax.swing.*;
import javax.swing.border.*;
import java.awt.*;


/**
 * This class describes a theme using gray colors.
 * 1.3 07/22/99
 * @author Steve Wilson
 */
public class EX5Theme extends DefaultMetalTheme {

    public String getName() { return "EX5"; }

    private final ColorUIResource primary1 = new ColorUIResource(0, 0, 0);
    private final ColorUIResource primary2 = new ColorUIResource(0, 0, 0);
    private final ColorUIResource primary3 = new ColorUIResource(0, 0, 0);

    private final ColorUIResource secondary1 = new ColorUIResource(0, 0, 0);
    private final ColorUIResource secondary2 = new ColorUIResource(100, 155 , 0);
    private final ColorUIResource secondary3 = new ColorUIResource(140, 164, 188);

    private final ColorUIResource black = new ColorUIResource(0, 0, 0);
    private final ColorUIResource white = new ColorUIResource(255, 255, 255);

    private final ColorUIResource blue = new ColorUIResource(49, 69, 90);
    private final ColorUIResource green = new ColorUIResource(200, 255 ,25);


    protected ColorUIResource getPrimary1() { return primary1; }
    protected ColorUIResource getPrimary2() { return primary2; }
    protected ColorUIResource getPrimary3() { return primary3; }

    protected ColorUIResource getSecondary1() { return secondary1; }
    protected ColorUIResource getSecondary2() { return secondary2; }
    protected ColorUIResource getSecondary3() { return secondary3; }

    protected ColorUIResource getBlue() { return blue; }
    protected ColorUIResource getGreen() { return green; }

    protected ColorUIResource getBlack() { return black; }
    protected ColorUIResource getWhite() { return white; }
    public ColorUIResource getControlHighlight() { return getSecondary3(); }
    public ColorUIResource getFocusColor() { return getBlack(); }

    public ColorUIResource getTextHighlightColor()  { return getSecondary2(); }
    public ColorUIResource getHighlightedTextColor() { return getWhite(); }

    public ColorUIResource getMenuSelectedBackground() { return getBlue(); }
    public ColorUIResource getMenuSelectedForeground() { return getBlack(); }
    public ColorUIResource getAcceleratorForeground() { return getWhite(); }
    public ColorUIResource getAcceleratorSelectedForeground() { return getBlack(); }

    public ColorUIResource getDesktopColor()  { return getBlue(); }
    public ColorUIResource getControl()  { return getBlue(); }
    public ColorUIResource getControlShadow() { return getBlack(); }
    public ColorUIResource getControlDarkShadow() { return getBlack(); }
    public ColorUIResource getControlInfo()  { return getSecondary3(); }
    public ColorUIResource getControlDisabled()  { return getGreen(); }
    public ColorUIResource getPrimaryControl()  { return getSecondary3(); }
    public ColorUIResource getPrimaryControlShadow() { return getSecondary3(); }
    public ColorUIResource getPrimaryControlDarkShadow() { return getBlack(); }
    public ColorUIResource getPrimaryControlInfo(){ return getSecondary2(); }
    public ColorUIResource getPrimaryControlHighlight() { return getWhite(); }
    public ColorUIResource getSystemTextColor() { return getWhite(); }
    public ColorUIResource getControlTextColor() { return getBlack(); }
    public ColorUIResource getInactiveControlTextColor() { return getBlack(); }
    public ColorUIResource getInactiveSystemTextColor() { return getBlack(); }
    public ColorUIResource getUserTextColor() { return getBlack(); }
    public ColorUIResource getWindowBackground() { return getGreen(); }
    public ColorUIResource getWindowTitleBackground() { return getBlue(); }
    public ColorUIResource getWindowTitleForeground(){ return getWhite(); }
    public ColorUIResource getWindowTitleInactiveBackground() { return getBlue(); }
    public ColorUIResource getWindowTitleInactiveForeground(){ return getWhite(); }
    public ColorUIResource getMenuBackground()  { return getBlue(); }
    public ColorUIResource getMenuForeground() { return getWhite(); }
    public ColorUIResource getMenuDisabledForeground()  { return getBlue(); }
    public ColorUIResource getSeparatorBackground() { return getBlue(); }
    public ColorUIResource getSeparatorForeground(){ return getWhite(); }

    public void addCustomEntriesToTable(UIDefaults table) {

        Border blackLineBorder = new BorderUIResource(new LineBorder( getBlack() ));
        Border whiteLineBorder = new BorderUIResource(new LineBorder( getWhite() ));

	      Object textBorder = new BorderUIResource( new CompoundBorder(
						                blackLineBorder,
					                  new BasicBorders.MarginBorder()));

        table.put( "ToolTip.border", blackLineBorder);
    	  table.put( "TitledBorder.border", blackLineBorder);
        table.put( "Table.focusCellHighlightBorder", whiteLineBorder);
        table.put( "Table.focusCellForeground", getBlack());
        table.put( "TextField.border", textBorder);
        table.put( "PasswordField.border", textBorder);
        table.put( "TextArea.border", textBorder);
        table.put( "TextPane.font", getBlack());
    }

}
